@@ -1,11 +1,13 @@
 import os
 
 import pytest
+from six.moves import http_client as httplib
 
 from vcr import VCR, use_cassette
 from vcr.compat import mock
 from vcr.request import Request
 from vcr.stubs import VCRHTTPSConnection
+from vcr.patch import _HTTPConnection, force_reset
 
 
 def test_vcr_use_cassette():
@@ -45,31 +47,44 @@ def test_vcr_before_record_request_params():
         if request.path != '/get':
             return request
 
-    test_vcr = VCR(filter_headers=('cookie',), before_record_request=before_record_cb,
+    test_vcr = VCR(filter_headers=('cookie', ('bert', 'ernie')),
+                   before_record_request=before_record_cb,
                    ignore_hosts=('www.test.com',), ignore_localhost=True,
-                   filter_query_parameters=('foo',))
+                   filter_query_parameters=('foo', ('tom', 'jerry')),
+                   filter_post_data_parameters=('posted', ('no', 'trespassing')))
 
     with test_vcr.use_cassette('test') as cassette:
-        assert cassette.filter_request(Request('GET', base_path + 'get', '', {})) is None
-        assert cassette.filter_request(Request('GET', base_path + 'get2', '', {})) is not None
+        # Test explicit before_record_cb
+        request_get = Request('GET', base_path + 'get', '', {})
+        assert cassette.filter_request(request_get) is None
+        request = Request('GET', base_path + 'get2', '', {})
+        assert cassette.filter_request(request) is not None
 
-        assert cassette.filter_request(Request('GET', base_path + '?foo=bar', '', {})).query == []
-        assert cassette.filter_request(
-            Request('GET', base_path + '?foo=bar', '',
-                    {'cookie': 'test', 'other': 'fun'})).headers == {'other': 'fun'}
-        assert cassette.filter_request(
-            Request(
-                'GET', base_path + '?foo=bar', '',
-                {'cookie': 'test', 'other': 'fun'}
-            )
-        ).headers == {'other': 'fun'}
+        # Test filter_query_parameters
+        request = Request('GET', base_path + '?foo=bar', '', {})
+        assert cassette.filter_request(request).query == []
+        request = Request('GET', base_path + '?tom=nobody', '', {})
+        assert cassette.filter_request(request).query == [('tom', 'jerry')]
 
-        assert cassette.filter_request(Request('GET', 'http://www.test.com' + '?foo=bar', '',
-                                               {'cookie': 'test', 'other': 'fun'})) is None
+        # Test filter_headers
+        request = Request('GET', base_path + '?foo=bar', '',
+                          {'cookie': 'test', 'other': 'fun', 'bert': 'nobody'})
+        assert (cassette.filter_request(request).headers ==
+                {'other': 'fun', 'bert': 'ernie'})
+
+        # Test ignore_hosts
+        request = Request('GET', 'http://www.test.com' + '?foo=bar', '',
+                          {'cookie': 'test', 'other': 'fun'})
+        assert cassette.filter_request(request) is None
+
+        # Test ignore_localhost
+        request = Request('GET', 'http://localhost:8000' + '?foo=bar', '',
+                          {'cookie': 'test', 'other': 'fun'})
+        assert cassette.filter_request(request) is None
 
     with test_vcr.use_cassette('test', before_record_request=None) as cassette:
-        # Test that before_record can be overwritten with
-        assert cassette.filter_request(Request('GET', base_path + 'get', '', {})) is not None
+        # Test that before_record can be overwritten in context manager.
+        assert cassette.filter_request(request_get) is not None
 
 
 def test_vcr_before_record_response_iterable():
@@ -98,6 +113,43 @@ def test_vcr_before_record_response_iterable():
             assert mock_filter.call_count == 1
 
 
+def test_before_record_response_as_filter():
+    request = Request('GET', '/', '', {})
+    response = object()  # just can't be None
+
+    # Prevent actually saving the cassette
+    with mock.patch('vcr.cassette.save_cassette'):
+
+        filter_all = mock.Mock(return_value=None)
+        vcr = VCR(before_record_response=filter_all)
+        with vcr.use_cassette('test') as cassette:
+            cassette.append(request, response)
+            assert cassette.data == []
+            assert not cassette.dirty
+
+
+def test_vcr_path_transformer():
+    # Regression test for #199
+
+    # Prevent actually saving the cassette
+    with mock.patch('vcr.cassette.save_cassette'):
+
+        # Baseline: path should be unchanged
+        vcr = VCR()
+        with vcr.use_cassette('test') as cassette:
+            assert cassette._path == 'test'
+
+        # Regression test: path_transformer=None should do the same.
+        vcr = VCR(path_transformer=None)
+        with vcr.use_cassette('test') as cassette:
+            assert cassette._path == 'test'
+
+        # and it should still work with cassette_library_dir
+        vcr = VCR(cassette_library_dir='/foo')
+        with vcr.use_cassette('test') as cassette:
+            assert cassette._path == '/foo/test'
+
+
 @pytest.fixture
 def random_fixture():
     return 1
@@ -243,6 +295,7 @@ def test_path_transformer():
 
 def test_cassette_name_generator_defaults_to_using_module_function_defined_in():
     vcr = VCR(inject_cassette=True)
+
     @vcr.use_cassette
     def function_name(cassette):
         assert cassette._path == os.path.join(os.path.dirname(__file__),
@@ -274,3 +327,40 @@ def test_additional_matchers():
 
     function_defaults()
     function_additional()
+
+
+def test_decoration_should_respect_function_return_value():
+    vcr = VCR()
+    ret = 'a-return-value'
+
+    @vcr.use_cassette
+    def function_with_return():
+        return ret
+
+    assert ret == function_with_return()
+
+
+class TestVCRClass(VCR().test_case()):
+
+    def no_decoration(self):
+        assert httplib.HTTPConnection == _HTTPConnection
+        self.test_dynamically_added()
+        assert httplib.HTTPConnection == _HTTPConnection
+
+    def test_one(self):
+        with force_reset():
+            self.no_decoration()
+        with force_reset():
+            self.test_two()
+        assert httplib.HTTPConnection != _HTTPConnection
+
+    def test_two(self):
+        assert httplib.HTTPConnection != _HTTPConnection
+
+
+def test_dynamically_added(self):
+    assert httplib.HTTPConnection != _HTTPConnection
+
+
+TestVCRClass.test_dynamically_added = test_dynamically_added
+del test_dynamically_added
