@@ -75,7 +75,7 @@ class CassetteContextDecorator(object):
             lambda key, _: key in self._non_cassette_arguments,
             self._args_getter()
         )
-        if 'path_transformer' in other_kwargs:
+        if other_kwargs.get('path_transformer'):
             transformer = other_kwargs['path_transformer']
             cassette_kwargs['path'] = transformer(cassette_kwargs['path'])
         self.__finish = self._patch_generator(self.cls.load(**cassette_kwargs))
@@ -127,7 +127,7 @@ class CassetteContextDecorator(object):
 
     def _handle_function(self, function, args, kwargs):
         with self as cassette:
-            self.__handle_function(cassette, function, args, kwargs)
+            return self.__handle_function(cassette, function, args, kwargs)
 
     @staticmethod
     def get_function_name(function):
@@ -211,6 +211,8 @@ class Cassette(object):
         if not request:
             return
         response = self._before_record_response(response)
+        if response is None:
+            return
         self.data.append((request, response))
         self.dirty = True
 
